guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

01/03: gnu: glibc-intermediate: Fixup the pre-configure phase.


From: guix-commits
Subject: 01/03: gnu: glibc-intermediate: Fixup the pre-configure phase.
Date: Thu, 23 Jul 2020 16:03:16 -0400 (EDT)

niedzejkob pushed a commit to branch core-updates
in repository guix.

commit 7cde865f12dd67e55946a52a21103e71f447eced
Author: Jakub Kądziołka <kuba@kadziolka.net>
AuthorDate: Wed Jul 8 17:21:22 2020 +0200

    gnu: glibc-intermediate: Fixup the pre-configure phase.
    
    * gnu/packages/commencement.scm
      (glibc-final-with-bootstrap-bash)[arguments]: Don't patch sunrpc,
      as it's no longer required. Tweak C_INCLUDE_PATH and
      CPLUS_INCLUDE_PATH instead of CPATH.
---
 gnu/packages/commencement.scm | 13 +++----------
 1 file changed, 3 insertions(+), 10 deletions(-)

diff --git a/gnu/packages/commencement.scm b/gnu/packages/commencement.scm
index 59ef5d0..ecd8073 100644
--- a/gnu/packages/commencement.scm
+++ b/gnu/packages/commencement.scm
@@ -3273,9 +3273,9 @@ memoized as a function of '%current-system'."
             `(modify-phases ,phases
                (add-before 'configure 'pre-configure
                  (lambda* (#:key inputs #:allow-other-keys)
-                   ;; Don't clobber CPATH with the bootstrap libc.
-                   (setenv "NATIVE_CPATH" (getenv "CPATH"))
-                   (unsetenv "CPATH")
+                   ;; Don't clobber include paths with the bootstrap libc.
+                   (unsetenv "C_INCLUDE_PATH")
+                   (unsetenv "CPLUS_INCLUDE_PATH")
 
                    ;; Tell 'libpthread' where to find 'libihash' on Hurd 
systems.
                    ,@(if (hurd-system?)
@@ -3286,13 +3286,6 @@ memoized as a function of '%current-system'."
                                            (assoc-ref %build-inputs 
"kernel-headers")
                                            "/lib/libihash.a\n"))))
                        '())
-
-                   ;; 'rpcgen' needs native libc headers to be built.
-                   (substitute* "sunrpc/Makefile"
-                     (("sunrpc-CPPFLAGS =.*" all)
-                      (string-append "CPATH = $(NATIVE_CPATH)\n"
-                                     "export CPATH\n"
-                                     all "\n")))
                    #t)))))))
     (propagated-inputs `(("kernel-headers" ,(kernel-headers-boot0))))
     (native-inputs



reply via email to

[Prev in Thread] Current Thread [Next in Thread]